@@ -6,28 +6,36 @@ use fuel_tx::ValidationError;
 use std::convert::Infallible as StdInfallible;
 use std::error::Error as StdError;
 use std::{fmt, io};
+use thiserror::Error;
 
 /// Interpreter runtime error variants.
-#[derive(Debug)]
+#[derive(Debug, Error)]
 pub enum InterpreterError {
     /// The instructions execution resulted in a well-formed panic, caused by an
     /// explicit instruction.
+    #[error("Execution error: {0:?}")]
     PanicInstruction(InstructionResult),
     /// The VM execution resulted in a well-formed panic. This panic wasn't
     /// caused by an instruction contained in the transaction or a called
     /// contract.
+    #[error("Execution error: {0:?}")]
     Panic(PanicReason),
     /// The provided transaction isn't valid.
-    ValidationError(ValidationError),
+    #[error("Failed to validate the transaction: {0}")]
+    ValidationError(#[from] ValidationError),
     /// The predicate verification failed.
+    #[error("Execution error")]
     PredicateFailure,
     /// No transaction was initialized in the interpreter. It cannot provide
     /// state transitions.
+    #[error("Execution error")]
     NoTransactionInitialized,
     /// I/O and OS related errors.
-    Io(io::Error),
+    #[error("Unrecoverable error: {0}")]
+    Io(#[from] io::Error),
 
     #[cfg(feature = "debug")]
+    #[error("Execution error")]
     /// The debug state is not initialized; debug routines can't be called.
     DebugStateNotInitialized,
 }
@@ -76,44 +84,6 @@ impl InterpreterError {
     }
 }
 
-impl From<io::Error> for InterpreterError {
-    fn from(e: io::Error) -> Self {
-        InterpreterError::Io(e)
-    }
-}
-
-impl fmt::Display for InterpreterError {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        match self {
-            Self::ValidationError(e) => {
-                write!(f, "Failed to validate the transaction: {}", e)
-            }
-
-            Self::Io(e) => {
-                write!(f, "Unrecoverable error: {}", e)
-            }
-
-            _ => write!(f, "Execution error: {:?}", self),
-        }
-    }
-}
-
-impl StdError for InterpreterError {
-    fn source(&self) -> Option<&(dyn StdError + 'static)> {
-        match self {
-            Self::ValidationError(e) => Some(e),
-            Self::Io(e) => Some(e),
-            _ => None,
-        }
-    }
-}
-
-impl From<ValidationError> for InterpreterError {
-    fn from(e: ValidationError) -> Self {
-        Self::ValidationError(e)
-    }
-}
-
 impl From<InstructionResult> for InterpreterError {
     fn from(r: InstructionResult) -> InterpreterError {
         Self::PanicInstruction(r)
@@ -129,15 +99,17 @@ impl From<RuntimeError> for InterpreterError {
     }
 }
 
-#[derive(Debug)]
+#[derive(Debug, Error)]
 #[cfg_attr(feature = "serde-types-minimal", derive(serde::Serialize, serde::Deserialize))]
 /// Runtime error description that should either be specified in the protocol or
 /// halt the execution.
 pub enum RuntimeError {
     /// Specified error with well-formed fallback strategy.
-    Recoverable(PanicReason),
+    #[error(transparent)]
+    Recoverable(#[from] PanicReason),
     /// Unspecified error that should halt the execution.
-    Halt(io::Error),
+    #[error(transparent)]
+    Halt(#[from] io::Error),
 }
 
 impl RuntimeError {
@@ -160,36 +132,6 @@ impl RuntimeError {
     }
 }
 
-impl From<PanicReason> for RuntimeError {
-    fn from(r: PanicReason) -> Self {
-        RuntimeError::Recoverable(r)
-    }
-}
-
-impl From<io::Error> for RuntimeError {
-    fn from(e: io::Error) -> Self {
-        RuntimeError::Halt(e)
-    }
-}
-
-impl fmt::Display for RuntimeError {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        match self {
-            Self::Recoverable(e) => e.fmt(f),
-            Self::Halt(e) => e.fmt(f),
-        }
-    }
-}
-
-impl StdError for RuntimeError {
-    fn source(&self) -> Option<&(dyn StdError + 'static)> {
-        match self {
-            Self::Recoverable(e) => Some(e),
-            Self::Halt(e) => Some(e),
-        }
-    }
-}
-
 #[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
 /// Infallible implementation that converts into [`io::Error`].
 pub struct Infallible(StdInfallible);
