@@ -7,20 +7,20 @@ impl<S> Interpreter<S>
 where
     S: InterpreterStorage,
 {
-    /// Set the appropriate change output values after execution has concluded.
-    pub(crate) fn update_change_amounts(
-        &mut self,
-        unused_gas_cost: Word,
-        revert: bool,
-    ) -> Result<(), InterpreterError> {
+    /// Finalize outputs post-execution.
+    /// Set the appropriate change output values.
+    /// Revert variable output amounts as needed
+    /// TODO: do we want to set contract outputs in memory?
+    pub(crate) fn finalize_outputs(&mut self, unused_gas_cost: Word, revert: bool) -> Result<(), InterpreterError> {
         let init_balances = Self::initial_free_balances(&self.tx)?;
 
         let mut update_outputs = match &self.tx {
             Transaction::Script { outputs, .. } => outputs.clone(),
             Transaction::Create { outputs, .. } => outputs.clone(),
         };
+
         // Update each output based on free balance
-        for output in update_outputs.iter_mut() {
+        for (idx, output) in update_outputs.iter_mut().enumerate() {
             if let Output::Change { asset_id, amount, .. } = output {
                 let refund = if *asset_id == AssetId::default() {
                     unused_gas_cost
@@ -28,25 +28,27 @@ where
                     0
                 };
 
-                if revert {
-                    *amount = init_balances[asset_id] + refund;
+                // Safety: initialization verifies that every output has a compatible input asset
+                // by returning a TransactionOutputChangeAssetIdNotFound or
+                // TransactionOutputCoinAssetIdNotFound error for missing inputs.
+                let final_amount = if revert {
+                    init_balances[asset_id] + refund
                 } else {
                     let balance = self.external_asset_id_balance(asset_id)?;
-                    *amount = balance + refund;
-                }
+                    balance + refund
+                };
+
+                *amount = final_amount;
+                self.set_output(idx, *output)?;
             }
             if let Output::Variable { amount, .. } = output {
                 if revert {
                     // reset amounts to zero on revert
                     *amount = 0;
+                    self.set_output(idx, *output)?;
                 }
             }
         }
-        // set outputs on tx
-        match &mut self.tx {
-            Transaction::Script { outputs, .. } => *outputs = update_outputs,
-            Transaction::Create { outputs, .. } => *outputs = update_outputs,
-        }
 
         Ok(())
     }
